<?php
define('THEME_DOMAIN', 'nineteenzerotwo');

if(!defined('THEME_STYLES_DIRECTORY'))
{
	define('THEME_STYLES_DIRECTORY', get_template_directory() . '/styles/');
}
if(!defined('THEME_STYLES_URI'))
{
	define('THEME_STYLES_URI', get_template_directory_uri() . '/styles/');
}

if ( !function_exists( 'wptheme03_init' ) ) {
	require_once dirname( __FILE__ ) . '/admin/theme-options.php';
}

include_once dirname( __FILE__ ) . '/includes/theme-init.php';

/**
 * nineteenzerotwo functions and definitions
 *
 * @package nineteenzerotwo
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 640; /* pixels */

if ( ! function_exists( 'nineteenzerotwo_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function nineteenzerotwo_setup() {

	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on nineteenzerotwo, use a find and replace
	 * to change 'nineteenzerotwo' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'nineteenzerotwo', get_template_directory() . '/languages' );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );

	/**
	 * Enable support for Post Thumbnails on posts and pages
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	
  add_theme_support( 'post-thumbnails' );

	/**
	 * This theme uses wp_nav_menu() in one location.
	 */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'nineteenzerotwo' ),
	) );

	/**
	 * Enable support for Post Formats
	 */
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );

	/**
	 * Setup the WordPress core custom background feature.
	 */
	add_theme_support( 'custom-background', apply_filters( 'nineteenzerotwo_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
}

endif; // nineteenzerotwo_setup
add_action( 'after_setup_theme', 'nineteenzerotwo_setup' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function nineteenzerotwo_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Main Sidebar', 'nineteenzerotwo' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Top Social Media', 'nineteenzerotwo' ),
		'id'            => 'socialmedia-links',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Sidebar 1', 'nineteenzerotwo' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer Sidebar 2', 'nineteenzerotwo' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'nineteenzerotwo_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function nineteenzerotwo_scripts() {
	wp_enqueue_style( 'nineteenzerotwo-style', get_stylesheet_uri() );
	
  //wp_enqueue_style( 'nineteenzerotwo-style1', get_stylesheet_directory_uri().'/styles/style1/style1.css' );
	
	$style_dir = get_theme_option('theme_style');
	$style_dir = ($style_dir) ? $style_dir : 'style1';
	wp_enqueue_style( 'nineteenzerotwo-style1', THEME_STYLES_URI . $style_dir . '/style.css' );
	wp_enqueue_style( 'nineteenzerotwo-responsive', get_stylesheet_directory_uri().'/responsive.css' );
	wp_enqueue_script('nineteenzerotwo-jquery-lib','http://ajax.googleapis.com/ajax/libs/jquery/1/jquery.min.js');
	wp_enqueue_script( 'nineteenzerotwo-script', get_stylesheet_directory_uri().'/js/1902theme03.js' );
	wp_enqueue_script( 'nineteenzerotwo-flexslider', get_template_directory_uri() . '/js/jquery.flexslider.js', array(), '1.0', true );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	
}
add_action( 'wp_enqueue_scripts', 'nineteenzerotwo_scripts' );

if ( ! function_exists( 'nineteenzerotwo_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post�date/time and author.
 */
function nineteenzerotwo_posted_on() {
	// use the "byline" class to hide the author name and link. We should make this appear automatically with a multi-author conditional tag in the future
	printf( __( '<span class="%1$s">Posted on</span> %2$s <span class="%4$s"><span class="meta-sep">by</span> %3$s</span>', 'nineteenzerotwo' ),
		'meta-prep meta-prep-author',
		sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><span class="entry-date">%3$s</span></a>',
			get_permalink(),
			esc_attr( get_the_time() ),
			get_the_date()
		),
		sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s">%3$s</a></span>',
			get_author_posts_url( get_the_author_meta( 'ID' ) ),
			sprintf( esc_attr__( 'View all posts by %s', 'nineteenzerotwo' ), get_the_author() ),
			get_the_author()
		),
		'byline'
	);
}
endif;

if ( ! function_exists( 'nineteenzerotwo_posted_in' ) ) :
/**
 * Prints HTML with meta information for the current post (category, tags and permalink).
 */
function nineteenzerotwo_posted_in() {
	// Retrieves tag list of current post, separated by commas.
	$tag_list = get_the_tag_list( '', ', ' );
	if ( $tag_list ) {
		$posted_in = __( 'This entry was posted in %1$s and tagged %2$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'nineteenzerotwo' );
	} elseif ( is_object_in_taxonomy( get_post_type(), 'category' ) ) {
		$posted_in = __( 'This entry was posted in %1$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'nineteenzerotwo' );
	} else {
		$posted_in = __( 'Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'nineteenzerotwo' );
	}
	// Prints the string, replacing the placeholders.
	printf(
		$posted_in,
		get_the_category_list( ', ' ),
		$tag_list,
		get_permalink(),
		the_title_attribute( 'echo=0' )
	);
}
endif;


/**
 * Returns true if a blog has more than 1 category
 */
function nineteenzerotwo_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'all_the_cool_cats' ) ) ) {
		// Create an array of all the categories that are attached to posts
		$all_the_cool_cats = get_categories( array(
			'hide_empty' => 1,
		) );

		// Count the number of categories that are attached to the posts
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'all_the_cool_cats', $all_the_cool_cats );
	}

	if ( '1' != $all_the_cool_cats ) {
		// This blog has more than 1 category so mysample_categorized_blog should return true
		return true;
	} else {
		// This blog has only 1 category so mysample_categorized_blog should return false
		return false;
	}
}



if ( ! function_exists( 'nineteenzerotwo_content_nav' ) ) :
/**
 * Display navigation to next/previous pages when applicable
 */
function nineteenzerotwo_content_nav( $nav_id ) {
	global $wp_query, $post;

	// Don't print empty markup on single pages if there's nowhere to navigate.
	if ( is_single() ) {
		$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
		$next = get_adjacent_post( false, '', false );

		if ( ! $next && ! $previous )
			return;
	}

	// Don't print empty markup in archives if there's only one page.
	if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) )
		return;

	$nav_class = ( is_single() ) ? 'post-navigation' : 'paging-navigation';

	?>
	<nav role="navigation" id="<?php echo esc_attr( $nav_id ); ?>" class="<?php echo $nav_class; ?>">
	<?php if ( is_single() ) : // navigation links for single posts ?>

		<?php previous_post_link( '<div class="nav-previous span490 alignleft">%link</div>', '<span class="meta-nav">' . _x( '&larr;', 'Previous post link', 'nineteen02' ) . '</span> %title' ); ?>
		<?php next_post_link( '<div class="nav-next span490 alignleft">%link</div>', '%title <span class="meta-nav">' . _x( '&rarr;', 'Next post link', 'nineteen02' ) . '</span>' ); ?>

	<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages ?>

		<?php if ( get_next_posts_link() ) : ?>
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'nineteen02' ) ); ?></div>
		<?php endif; ?>

		<?php if ( get_previous_posts_link() ) : ?>
		<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'nineteen02' ) ); ?></div>
		<?php endif; ?>

	<?php endif; ?>

	</nav><!-- #<?php echo esc_html( $nav_id ); ?> -->
	<?php
}
endif; // nineteenzerotwo_content_nav




if ( ! function_exists( 'nineteenzerotwo_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 */
function nineteenzerotwo_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;

	if ( 'pingback' == $comment->comment_type || 'trackback' == $comment->comment_type ) : ?>

	<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
		<div class="comment-body">
			<?php _e( 'Pingback:', 'nineteen02' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( 'Edit', 'nineteen02' ), '<span class="edit-link">', '</span>' ); ?>
		</div>

	<?php else : ?>

	<li id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
		<article id="div-comment-<?php comment_ID(); ?>" class="comment-body">
        		<div class="alignleft">
        		    	<div class="comment-author vcard">
        					<?php if ( 0 != $args['avatar_size'] ) echo get_avatar( $comment, 67 ); ?>
        					<?php //printf( __( '%s <span class="says">says:</span>', 'nineteen02' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
        				</div><!-- .comment-author -->
        		</div>
            <div class="alignleft span850">
             
        				<div class="comment-author">
                <?php echo get_comment_author(); ?>
                </div>
                <div class="comment-metadata ">
        					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
        						<time datetime="<?php comment_time( 'c' ); ?>">
        							<?php printf( _x( '%1$s at %2$s', '1: date, 2: time', 'nineteen02' ), get_comment_date(), get_comment_time() ); ?>
        						</time>
        					</a>
        					<?php edit_comment_link( __( 'Edit', 'nineteen02' ), '<span class="edit-link">', '</span>' ); ?>
        				</div><!-- .comment-metadata -->
        
        				<?php if ( '0' == $comment->comment_approved ) : ?>
        				<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'nineteen02' ); ?></p>
        				<?php endif; ?>
        		
        
        			<div class="comment-content">
        				<?php comment_text(); ?>
        			</div><!-- .comment-content -->
        
        			<div class="reply">
        				<?php comment_reply_link( array_merge( $args, array( 'add_below' => 'div-comment', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
        			</div><!-- .reply -->
        	</div>
        	<div class="clear"></div>
		</article><!-- .comment-body -->

	<?php
	endif;
}
endif; // ends check for nineteenzerotwo_comment()


//add_filter( 'body_class', 'nineteenzerotwo_style_selector_body_classes' );
/**
 * Adds style selector classes to the body classes.
 */
function nineteenzerotwo_style_selector_body_classes( $classes ) {
	$theme_style = get_theme_option('theme_style');
	$styleSelected = $theme_style;
	
	if ( $styleSelected )
		$classes[] = esc_attr( sanitize_html_class( $styleSelected ) );

	return $classes;

}

function custom_excerpt_length($length) {
    return 50;
}
add_filter( 'excerpt_length', 'custom_excerpt_length');


function new_excerpt_more( $more ) {
	return ' <a class="readmore" href="'. get_permalink( get_the_ID() ) . '">Read More</a>';
}
add_filter( 'excerpt_more', 'new_excerpt_more' );


/*Customizing excerpt length*/
function custom_length($content, $chars='70',$link='...')
{
      
		  $lenght = strlen(strip_tags($content));
      $excerpt = preg_replace(" (\[.*?\])", '', $content);
	    $excerpt = strip_shortcodes($excerpt);
	    $excerpt = strip_tags($excerpt);
	    $excerpt = substr($excerpt, 0, $chars);
	    $excerpt = substr($excerpt, 0, strripos($excerpt, " "));
	    $excerpt = trim(preg_replace( '/\s+/', ' ', $excerpt));
	    $excerpt = trim(html_entity_decode(str_replace("&nbsp;"," ", $excerpt)));
      $excerpt = $excerpt . ' ' . $link;
	    if($lenght > $chars) 
      {
	       return $excerpt;
	    } 
      else 
      {
          return $content;
      }
}

// Output custom CSS to live site
add_action('wp_head', 'generate_custom_css');

function generate_custom_css() 
{
	$custom = get_option('wptheme03');
	
	if($custom['theme_style'] == 'custom')
	{
?>
	<!--Customizer CSS--> 
	<style type="text/css">
		.main-navigation { background-color: <?php echo $custom['nav_bgcolor']?>;}
		.main-navigation a { color: <?php echo $custom['nav_txtcolor']?>; }
		.main-navigation li.current-menu-parent > a,
		.main-navigation li.current_page_parent > a,
		.main-navigation li.current_page_item > a, 
		.main-navigation li.current-menu-item > a,
		.main-navigation li:last-child > a:hover,
		.main-navigation a:hover { background: <?php echo $custom['nav_hovercolor']?>;}    
		.popular h2.widgetTitle span { color: <?php echo $custom['footer_bgcolor']?>; }
		hr { background-color: <?php echo $custom['nav_bgcolor']?>; }}
		a { color: <?php echo $custom['link_color']?>;}
		button, html input[type="button"], input[type="submit"] { background: <?php echo $custom['button_bgcolor']?>; }
		html input[type="button"]:hover, input[type="submit"]:hover { background: <?php echo $custom['button_hovercolor']?>; }
		#footer, #footer p { color: <?php echo $custom['footer_txtcolor']?>; } 
		#footer .site-info { background-color: <?php echo $custom['footer_bgcolor']?>; }
		#footer .widget-title { background-color: <?php echo $custom['widget_bgcolor']?>; color: <?php echo $custom['widget_txtcolor']?>; } 
	</style> 
	<!--/Customizer CSS-->
<?php
	}
}


add_filter( 'body_class', 'nineteen02_custom_body_class', 15 );
function nineteen02_custom_body_class( $classes ) {
  $useragent = 'search: ' . strtolower($_SERVER['HTTP_USER_AGENT']);
  $browser_class = '';
  //echo $useragent;
  if (strpos($useragent, 'msie 10.') != false)
  {
  	$browser_class = 'ie10';
  }
  if (strpos($useragent, 'msie 9.') != false)
  {
  	$browser_class = 'ie9';
  }
  else if (strpos($useragent, 'msie 8.') != false)
  {
  	$browser_class = 'ie8';
  }
  else if (strpos($useragent, 'chrome') != false)
  {
  	$browser_class = 'chrome';
  }
  else if (strpos($useragent, 'firefox') != false)
  {
  	$browser_class = 'firefox';
  }
  else if (strpos($useragent, 'opera') != false)
  {
  	$browser_id = 'opera';
  }
  else if (strpos($useragent, 'safari') != false)
  {
  	$browser_class = 'safari';
  }

	
	$classes[] = $browser_class;

	return $classes;

}


//Make Tags on custom post type be worked
add_filter('pre_get_posts', 'query_post_type');
function query_post_type($query) {
  if(is_category() || is_tag()) {
    $post_type = get_query_var('post_type');
	if($post_type)
	    $post_type = $post_type;
	else
	    $post_type = array('post','news','product','nav_menu_item');
    $query->set('post_type',$post_type);
	return $query;
    }
}


/**
	 * Load javascripts used by the theme
	 */
function nineteen02_custom_post_theme_js(){
	    wp_register_script( 'infinite_scroll',  get_template_directory_uri() . '/js/jquery.infinitescroll.min.js', array('jquery'),null,true );
	    if( ! is_singular() ) {
	        wp_enqueue_script('infinite_scroll');
	    }
}
add_action('wp_enqueue_scripts', 'nineteen02_custom_post_theme_js');


/**
 * Infinite Scroll
 */
function nineteen02_custom_infinite_scroll_js() {
	if( ! is_singular() ) { ?>
	<script>
	var infinite_scroll = {
		loading: {
			img: "<?php echo get_template_directory_uri(); ?>/images/ajax-loader-whiteBG.gif",
			msgText: "<?php //_e( 'Loading the next set of posts...', 'nineteenzerotwo' ); ?>",
			finishedMsg: "<?php _e( 'All posts loaded.', 'nineteenzerotwo' ); ?>"
		},
		"nextSelector":"#nav-below .nav-previous a",
		"navSelector":"#nav-below",
		"itemSelector":"article",
		"contentSelector":"#content"
	};
	jQuery( infinite_scroll.contentSelector ).infinitescroll( infinite_scroll );
	</script>
	<?php
	}
}
add_action( 'wp_footer', 'nineteen02_custom_infinite_scroll_js',100 );


/**
 * If we go beyond the last page and request a page that doesn't exist,
 * force WordPress to return a 404.
 * See http://core.trac.wordpress.org/ticket/15770
 */
function nineteen02_custom_paged_404_fix( ) {
	global $wp_query;
	if ( is_404() || !is_paged() || 0 != count( $wp_query->posts ) )
		return;
	$wp_query->set_404();
	status_header( 404 );
	nocache_headers();
}
add_action( 'wp', 'nineteen02_custom_paged_404_fix' );


/* import on theme activation */
//add_action('after_switch_theme', 'import_theme_settings', 10, 2);
