<?php

//STARTS OF CONTACTS
add_action('init', 'register_contacts_post_type');

function register_contacts_post_type() 
{
	register_post_type( 'contacts',
                array( 
				'label' => __('Contacts', THEME_DOMAIN),
				'public' => false, 
				'show_ui' => true,
				'show_in_menu' => false,
				'hierarchical' => false,
				'menu_icon' => OPTIONS_ADMIN_URL.'images/icon.png',
				'capability_type' => 'page',
                                'register_meta_box_cb' => 'add_contacts_meta_box',
				'supports' => array(
						'title',
						'editor')
					) 
				);
}
	
function add_contacts_meta_box() 
{
	add_meta_box('contactsdiv', 'Contact Details', 'contacts_meta_box', 'contacts', 'normal', 'default');
}

function contacts_meta_box()
{
	global $post;
	
	$contact_title = get_post_meta($post->ID, 'contact_title', true);
	$contact_image = get_post_meta($post->ID, 'contact_image', true);
	
	require_once get_template_directory() . '/admin/includes/contacts-metabox.phtml';
}


add_action('save_post', 'save_contacts_meta');
function save_contacts_meta($post_id)
{
	if(isset($_POST['contacts_meta_box_nonce']))
	{
		if (!wp_verify_nonce($_POST['contacts_meta_box_nonce'], 'contacts-nonce')) 
		{
			return $post_id;
		}
	}
 
	// check autosave
	if( defined('DOING_AUTOSAVE') 
		&& DOING_AUTOSAVE 
		|| wp_is_post_autosave($post_id) ) {
		
		return $post_id;
	}
	
	if (get_post_status($post_id) == 'auto-draft')
	{
		return $post_id;
	}
	
	if (get_post_status($post_id) == 'trash')
	{
		return $post_id;
	}
	
	//on Post Revision do nothing special
	if (wp_is_post_revision($post_id)) {
		
		return $post_id;
	}
	
	//on Quick Edit do nothing special
	if (isset($_SERVER['HTTP_X_REQUESTED_WITH']) && $_SERVER['HTTP_X_REQUESTED_WITH'] == 'XMLHttpRequest') {
		
		return $post_id;
	}

	if(isset($_POST['post_type']))
	{
	      if ('contacts' == $_POST['post_type']) 
	      {
	              if (!current_user_can('edit_page', $post_id)) 
	              {
	                      return $post_id;
	              }
	      } 
	      elseif (!current_user_can('edit_post', $post_id)) 
	      {
	              return $post_id;
	      }
	
	      if(isset($_POST['contact']))
	      {
		      foreach($_POST['contact'] as $field=>$value) 
		      {
		              if(!empty($_POST['contact'][$field])) 
		              {
		                      update_post_meta($post_id,  'contact_' . $field, $value);
		              }
		              else
		              {
		                      delete_post_meta($post_id, 'contact_' . $field);
		              }
		      }
	      }
	}

}

add_shortcode('contacts', 'show_all_contacts');
function show_all_contacts()
{
	$args = array(
				'post_type'		=> 'contacts',
				'post_status'	=> 'publish'
			);
			
	$contacts = new WP_Query($args);
	
	$option_base = get_option('wptheme03');
  $use_rounded_image = $option_base['use_rounded_image'];
  $contactlist_header = $option_base['contactlist_header'];
  
  $imageclass='';
  if($use_rounded_image =='Yes')
      $imageclass = 'rounded';
    else
      $imageclass = '';
        
	echo '<div class="fullwidth organization">';
        	echo '<h2 class="widgetTitle">'.$contactlist_header.'</h2>';
        	echo '<div class="row">';
        	$count = 0;
        	$total = $contacts->post_count;
        	while($contacts->have_posts())
        	{
        		$count++;
        		$contacts->the_post();	
        		$image = get_post_meta(get_the_ID(), 'contact_image', true);
        		$title = get_post_meta(get_the_ID(), 'contact_title', true);
        ?>
        		
                  		<div class="span480 alignleft">	
                  				<div class="p-img">
                  					<img class="<?php echo $imageclass;?>" src="<?php echo INCLUDES_THEME_URL?>/timthumb.php?src=<?php echo $image; ?>&w=150&h=150" />
                  				</div>
                  				<div class="p-info">
                  				    <h3 class="p-name"><?php the_title()?></h2>
                    					<div class="p-role"><?php echo $title?></div>
                    					<div class="p-desc">
                    						<?php the_content()?>
                    					</div>
                  				</div>
                  	   </div>
                  	   <?php if($count % 2 == 0) {?>
        					<div class="clear"></div>
        				</div>
        					<?php if($count != $total) {?>
        						<div class="row">
        					<?php }?>
                  		<?php } else { ?>
                  				<?php if($count == $total) {?>
                  					<div class="clear"></div>
                  				<?php }?>
                  		<?php } ?>
        <?php 
        	}
        	echo '</div>';
	
  echo '</div>';
}

//END OF CONTACTS


/***START of INQUIRIES***/
add_action('init', 'register_inquiries_post_type');
add_action('admin_menu', 'remove_add_inquiry_submenu');
add_action('admin_head', 'hide_inquiry_add_new');

function register_inquiries_post_type() 
{
    register_post_type( 'inquiries',
              array( 
      		'label' => __('Inquiries', THEME_DOMAIN),
      		'public' => false, 
      		'show_ui' => true,
      		'show_in_menu' => false,
      		'hierarchical' => false,
      		'capability_type' => 'page',
                  'register_meta_box_cb' => 'add_inquiry_meta_box',
      		'supports' => array(
  				'title',
  				'editor')
  			) 
  		);
}

function remove_add_inquiry_submenu() 
{
		global $submenu;
		unset($submenu['edit.php?post_type=inquiries'][10]); // Removes 'Add New'.
}
	
function hide_inquiry_add_new() 
{
	global $pagenow;
	
	if(is_admin())
	{
	 if(isset($_GET['post_type'])){
  		if(($pagenow == 'edit.php' &&  $_GET['post_type'] == 'inquiries') || ($pagenow == 'post.php' &&  get_post_type() == 'inquiries'))
  		{
  		  	echo '<style type="text/css">.add-new-h2, #side-sortables, #wp-content-editor-tools {display: none;}</style>';
  		} 
    } 
	}

}

function add_inquiry_meta_box() 
{
	add_meta_box('inquirydiv', 'Inquiry Details', 'inquiry_meta_box', 'inquiries', 'normal', 'default');
}

function inquiry_meta_box()
{
	global $post;
	$inquiry_email = get_post_meta($post->ID, 'inquiry_email', true);
	$inquiry_subject = get_post_meta($post->ID, 'inquiry_subject', true);
	require_once get_template_directory() . '/admin/includes/inquiry-metabox.phtml';
}
/***END OF INQUIRIES***/



/*START OF News Custom Post type*/
add_action('init', 'register_news_post_type');
function register_news_post_type()
{
    $labels = array(
        'name' => _x('News & Updates', THEME_DOMAIN),
        'all_items' => __( 'News' , THEME_DOMAIN ),
        'singular_name' => _x('News', THEME_DOMAIN),
        'add_new' => _x('Add News', THEME_DOMAIN),
        'add_new_item' => __('Add New News', THEME_DOMAIN),
        'edit_item' => __('Edit News', THEME_DOMAIN),
        'new_item' => __('New News', THEME_DOMAIN),
        'view' => 'View',
        'view_item' => __('View News', THEME_DOMAIN),
        'search_items' => __('Search News', THEME_DOMAIN),
        'not_found' => __('Nothing found', THEME_DOMAIN),
        'not_found_in_trash' => __('Nothing found in Trash', THEME_DOMAIN),
        'parent_item_colon' => '',
        'parent' => 'Parent Menu'
    );
    $args = array(
        'labels' => $labels,
        'public' => true,
        'publicly_queryable' => true,
        'show_ui' => true,
        'query_var' => true,
        'rewrite' => true,
	      'capability_type' => 'post',
        'hierarchical' => false,
        'show_admin_column'   => true,
        'supports' => array(
                            'title', 
                            'editor', 
                            'thumbnail',
                            'page-attributes',
                            ),
        'exclude_from_search' => false,
        'show_in_menu' => false,   
        'has_archive' => true,
        'taxonomies' => array('post_tag')
     ); 

    
    add_post_type_support( 'news', 'excerpt' );
    
    register_post_type( 'news' , $args );
    flush_rewrite_rules();
}
add_action('save_post', 'save_news');
function save_news($post_id){ 

    global $post, $post_id;

    //on Autosave do nothing special
    if( defined('DOING_AUTOSAVE') 
        && DOING_AUTOSAVE 
        || wp_is_post_autosave($post_id) ) {

        return $post_id;
    }

    if (get_post_status($post_id) == 'auto-draft')
    {
        return $post_id;
    }

    if (get_post_status($post_id) == 'trash')
    {
        return $post_id;
    }

    //on Post Revision do nothing special
    if (wp_is_post_revision($post_id)) {
        return $post_id;
    }

    //on Quick Edit do nothing special
    if (isset($_SERVER['HTTP_X_REQUESTED_WITH']) && $_SERVER['HTTP_X_REQUESTED_WITH'] == 'XMLHttpRequest') {

        return $post_id;
    }

    if(get_post_type($post_id) != 'news')
    {	
        return $post_id;
    }

    update_post_meta($post_id, 'news');    
}
/*END OF News Custom Post type*/


/***START OF PRODUCT LINE***/
add_action('init', 'register_product_post_type');
function register_product_post_type()
{
    $labels = array(
        'name' => _x('Product Line', THEME_DOMAIN),
        'all_items' => __( 'Product Lists' , THEME_DOMAIN ),
        'singular_name' => _x('Product Lists', THEME_DOMAIN),
        'add_new' => _x('Add Product', THEME_DOMAIN),
        'add_new_item' => __('Add New Product', THEME_DOMAIN),
        'edit_item' => __('Edit Product', THEME_DOMAIN),
        'new_item' => __('New Product', THEME_DOMAIN),
        'view' => 'View',
        'view_item' => __('View Products', THEME_DOMAIN),
        'search_items' => __('Search Products', THEME_DOMAIN),
        'not_found' => __('Nothing found', THEME_DOMAIN),
        'not_found_in_trash' => __('Nothing found in Trash', THEME_DOMAIN),
        'parent_item_colon' => '',
        'parent' => 'Parent Menu'
    );
    $args = array(
        'labels' => $labels,
        'public' => true,
        'publicly_queryable' => true,
        'show_ui' => true,
        'query_var' => true,
        'rewrite' => true,
	      'capability_type' => 'post',
        'hierarchical' => false,
        'show_admin_column'   => true,
        'supports' => array(
                            'title', 
                            'editor', 
                            'thumbnail',
                            'page-attributes',
                            ),
        'exclude_from_search' => false,
        'show_in_menu' => false,   
        'has_archive' => true
     ); 
     
    add_post_type_support( 'product', 'excerpt' );
    register_post_type( 'product' , $args );
    flush_rewrite_rules();
}

add_action('init', 'register_custom_product_category');
function register_custom_product_category()
	{
		$labels = array(
			'name'                => _x( 'Product Categories', 'taxonomy general name' ),
			'menu_name'           => __( 'Product Categories' )
		); 	
		
		$args = array(
			'hierarchical'        => true,
			'labels'              => $labels,
			'show_ui'             => true,
			'show_admin_column'   => true,
			'query_var'           => true
		);		
		register_taxonomy( 'product_category', array( 'product' ), $args );
}

add_action( 'add_meta_boxes', 'add_product_metabox');
function add_product_metabox()
{
	add_meta_box('prdouctoptiondiv', __('Product other details', THEME_DOMAIN), 'add_product_other_options', 'product', 'side', 'high');
}	

function add_product_other_options()
{
		global $post;
	
		$price = ($price = get_post_meta($post->ID, 'product_price', true)) ? $price : '';	
		
		echo "<p>
				  <lable>" . __('Price:') . "</label>
				  <input type='text' name='product_price' value='".$price."' id='product_price'/>
			  </p>";
}
	
add_action('save_post', 'save_product');
function save_product($post_id){ 

    global $post, $post_id;

    //on Autosave do nothing special
    if( defined('DOING_AUTOSAVE') 
        && DOING_AUTOSAVE 
        || wp_is_post_autosave($post_id) ) {

        return $post_id;
    }

    if (get_post_status($post_id) == 'auto-draft')
    {
        return $post_id;
    }

    if (get_post_status($post_id) == 'trash')
    {
        return $post_id;
    }

    //on Post Revision do nothing special
    if (wp_is_post_revision($post_id)) {
        return $post_id;
    }

    //on Quick Edit do nothing special
    if (isset($_SERVER['HTTP_X_REQUESTED_WITH']) && $_SERVER['HTTP_X_REQUESTED_WITH'] == 'XMLHttpRequest') {

        return $post_id;
    }

    if(get_post_type($post_id) != 'product')
    {	
        return $post_id;
    }

    update_post_meta($post_id, 'product');
   
    if($_POST['product_price'])
		{
			update_post_meta($post_id, 'product_price', $_POST['product_price']);
		}
		else
		{
			delete_post_meta($post_id, 'product_price');
		}
        
}


function show_all_products_groupbycategory()
{

	$post_type = 'product';	
  $taxonomies = get_object_taxonomies( (object) array( 'post_type' => $post_type ) );
  
  foreach( $taxonomies as $taxonomy ) : 
      $terms = get_terms( $taxonomy );
      foreach( $terms as $term ) : 
          $args = array(
    				'taxonomy'		=> $taxonomy,
    				'term'	=> $term->slug,
    				'posts_per_page' => -1
    			);
    		
          $products = new WP_Query($args);
          require('products/product_list.phtml');         
      endforeach;
  endforeach;
}
add_shortcode('product_list','show_all_products_groupbycategory');


function show_all_product_categories()
{
	$args = array(
		'orderby'			=> 'name',
		'order'				=> 'ASC',
		'hide_empty'		=> true,
		'hierarchical'		=> true,
		'taxonomy'			=> 'product_category'
		);
		
	$categories = get_categories($args);
	
  require_once('products/product_categories.phtml');     

}
add_shortcode('product_categories','show_all_product_categories');


//PRODUCT_CATEGORY CUSTOM TAXONOMY
define( 'CATEGORY_IMAGE_PLACEHOLDER', get_template_directory_uri() . "/includes/category/images/placeholder.png");
define('INCLUDES_THEME_URL',get_template_directory_uri().'/includes');

add_action('admin_init', 'custom_tax_init');
function custom_tax_init() {
	$custom_taxonomies = get_taxonomies();
	if (is_array($custom_taxonomies)) {
	    foreach ($custom_taxonomies as $custom_taxonomy ) {
	        add_action($custom_taxonomy.'_add_form_fields', 'custom_add_texonomy_field');
    			add_action($custom_taxonomy.'_edit_form_fields', 'custom_edit_texonomy_field');
    			add_filter( 'manage_edit-' . $custom_taxonomy . '_columns', 'custom_taxonomy_columns' );
    			add_filter( 'manage_' . $custom_taxonomy . '_custom_column', 'custom_taxonomy_column', 10, 3 );
	    }
	}
}

function custom_tax_add_style() {
	wp_enqueue_style('thickbox');
  wp_enqueue_script('thickbox');
  wp_enqueue_script('customtax-js', INCLUDES_THEME_URL . '/category/js/customtax.js' );
  wp_enqueue_style('customtax-css', INCLUDES_THEME_URL . '/category/css/customtax.css' );
}

// add image field in add form
function custom_add_texonomy_field() {
  
	echo '<div class="form-field">
      		<label for="taxonomy_image">' . __('Icon', THEME_DOMAIN) . '</label>
      		<input type="text" name="taxonomy_image" id="taxonomy_image" value="" />
      		<br/>
      		<button class="custom_upload_image_button button">' . __('Upload/Add icon', THEME_DOMAIN) . '</button>
	     </div>';
	     
	echo '<div class="form-field">
	         <label for="taxonomy_gallery">' . __('Gallery', THEME_DOMAIN) . '</label>';
          echo '<div class="link_header">';
               
                $query_images_args = array(
                        'post_type' => 'attachment',
                        'post_mime_type' =>array(
                                        'jpg|jpeg|jpe' => 'image/jpeg',
                                        'gif' => 'image/gif',
                                        'png' => 'image/png',
                                        ),
                        'post_status' => 'inherit',
                        'posts_per_page' => -1,
                        );
                        
                $query_images = new WP_Query( $query_images_args );
                $images = array();
                echo '<div class="frame">';
                              
                          foreach ( $query_images->posts as $file) {
                               $imgsrc = wp_get_attachment_image_src( $file->ID, 'thumbnail');
                               echo '<label>
                                          <input type="checkbox" name="taxonomy_gallery[]" value="'.$images[]= $file->ID.'" />
                                          <img src="'.$imgsrc[0].'" width="60" height="60" /><span></span>
                                    </label>';
                          } 
                            
                          
                echo '</div></div>';
                echo '<div class="images_count"><a href="media-upload.php?type=image&amp;TB_iframe=1&amp;width=640&amp;height=715" id="add_image" class="upload-image thickbox button-secondary" title="">Upload Images</a><a id="updategallery" class="button-secondary">Update Gallery</a></div>';
   
   echo '</div>';
   
}

// add image field in edit form
function custom_edit_texonomy_field($taxonomy) {
	if (custom_taxonomy_image_url( $taxonomy->term_id, TRUE ) == CATEGORY_IMAGE_PLACEHOLDER) 
		$image_text = "";
	else
		$image_text = custom_taxonomy_image_url( $taxonomy->term_id, TRUE );
	
  echo '<tr class="form-field">
      		<th scope="row" valign="top"><label for="taxonomy_image">' . __('Icon', THEME_DOMAIN) . '</label></th>
      		<td><img class="taxonomy-image" src="' . custom_taxonomy_image_url( $taxonomy->term_id, TRUE ) . '"/><br/><input type="text" name="taxonomy_image" id="taxonomy_image" value="'.$image_text.'" /><br />
      		<button class="custom_upload_image_button button">' . __('Upload/Add icon', THEME_DOMAIN) . '</button>
      		<button class="custom_remove_image_button button">' . __('Remove icon', THEME_DOMAIN) . '</button>
      		<input type="hidden" id="defaultimage" value="'.CATEGORY_IMAGE_PLACEHOLDER.'" />
      		</td>
      	</tr>
        <tr class="form-field">
           <th scope="row" valign="top"><label for="taxonomy_gallery">' . __('Gallery', THEME_DOMAIN) . '</label></th>  
           <td>';
           echo '<div class="link_header">';
                $taxonomy_gallery = get_option('custom_taxonomy_gallery'.$taxonomy->term_id);
                //echo '<pre>';
                //var_dump($taxonomy_gallery);
                //echo '</pre>';
                $query_images_args = array(
                        'post_type' => 'attachment',
                        'post_mime_type' =>array(
                                        'jpg|jpeg|jpe' => 'image/jpeg',
                                        'gif' => 'image/gif',
                                        'png' => 'image/png',
                                        ),
                        'post_status' => 'inherit',
                        'posts_per_page' => -1,
                        );
                        
                $query_images = new WP_Query( $query_images_args );
                $images = array();
                echo '<div class="frame">';
                              
                          foreach ( $query_images->posts as $file) {
                               $imgsrc = wp_get_attachment_image_src( $file->ID, 'thumbnail');
                               if($taxonomy_gallery){
                                    if(in_array($images[]= $file->ID, $taxonomy_gallery)){
                    
                                       echo '<label><input type="checkbox" name="taxonomy_gallery[]" value="'.$images[]= $file->ID.'" checked />
                                                  <img src="'.$imgsrc[0].'" width="60" height="60" /><span></span>
                                                </label>';
                                         } else {
                                           
                                        echo '<label><input type="checkbox" name="taxonomy_gallery[]" value="'.$images[]= $file->ID.'" />
                                              <img src="'.$imgsrc[0].'" width="60" height="60" /><span></span></label>';
                                        }
                              } else {
                              
                                      echo '<label><input type="checkbox" name="taxonomy_gallery[]" value="'.$images[]= $file->ID.'" />
                                            <img src="'.$imgsrc[0].'" width="60" height="60" /><span></span></label>';
                              }
                          } 
                            
                          
                echo '</div></div>';
                echo '<div class="images_count"><a href="media-upload.php?type=image&amp;TB_iframe=1&amp;width=640&amp;height=715" id="add_image" class="upload-image thickbox button-secondary" title="">Upload Images</a><a id="updategallery" class="button-secondary">Update Gallery</a></div>';
                
           '</td>
        </tr>';
      
}


// save our taxonomy image while edit or save term
add_action('edit_term','custom_save_taxonomy_image');
add_action('create_term','custom_save_taxonomy_image');
function custom_save_taxonomy_image($term_id) {
    if(isset($_POST['taxonomy_image']))
        update_option('custom_taxonomy_image'.$term_id, $_POST['taxonomy_image']);
        
    if(isset($_POST['taxonomy_gallery']))  
        update_option('custom_taxonomy_gallery'.$term_id, $_POST['taxonomy_gallery']);
    
                  
}


// output taxonomy image url for the given term_id (NULL by default)
function custom_taxonomy_image_url($term_id = NULL, $return_placeholder = FALSE) {
	if (!$term_id) {
		if (is_category())
			$term_id = get_query_var('cat');
		elseif (is_tax()) {
			$current_term = get_term_by('slug', get_query_var('term'), get_query_var('taxonomy'));
			$term_id = $current_term->term_id;
		}
	}
	$taxonomy_image_url = get_option('custom_taxonomy_image'.$term_id);
	if ($return_placeholder)
		return ($taxonomy_image_url != "") ? $taxonomy_image_url : CATEGORY_IMAGE_PLACEHOLDER;
	else
		return $taxonomy_image_url;
}


/* Thumbnail column added to category admin. */
function custom_taxonomy_columns( $columns ) {
	$new_columns = array();
	$new_columns['cb'] = $columns['cb'];
	$new_columns['thumb'] = __('Icon', THEME_DOMAIN);

	unset( $columns['cb'] );

	return array_merge( $new_columns, $columns );
}

/**Thumbnail column value added to category admin.**/
function custom_taxonomy_column( $columns, $column, $id ) {
	if ( $column == 'thumb' )
		$columns = '<span><img src="' . custom_taxonomy_image_url($id, TRUE) . '" alt="' . __('Thumbnail', THEME_DOMAIN) . '" class="wp-post-image" /></span>';
	
	return $columns;
}

// change 'insert into post' to 'use this image'
add_filter("attribute_escape", "custom_change_insert_button_text", 10, 2);
function custom_change_insert_button_text($safe_text, $text) {
    return str_replace("Insert into Post", "Use this image", $text);
}

/* style the image in category list*/
if ( strpos( $_SERVER['SCRIPT_NAME'], 'edit-tags.php' ) > 0 ) {
  	add_action( 'admin_head', 'custom_tax_add_style' );
}
/***END OF PRODUCT LINE***/



/*START OF NINETEENO2 TWITTER FEED*/
function nineteen02_makeLink($nineteen02_tweet_con) {

	$nineteen02_tweet_con = preg_replace('@(https?://([-\w\.]+[-\w])+(:\d+)?(/([\w/_\.#-]*(\?\S+)?[^\.\s])?)?)@', '<a href="$1" target="_blank">$1</a>', $nineteen02_tweet_con);

	$nineteen02_tweet_con = preg_replace( '/@([a-zA-Z0-9]+)/', '<a href="https://twitter.com/\1" target="_blank">@\1</a>', $nineteen02_tweet_con ); 

	$nineteen02_tweet_con = preg_replace( '/#([a-zA-Z0-9-]+)/', '<a href="https://twitter.com/search?q=%23\1&src=hash" target="_blank">#\1</a>', $nineteen02_tweet_con ); 

	return $nineteen02_tweet_con;

}

		

// parse time in a twitter style
function nineteen02_getTime($nineteen02_date)

{

	$nineteen02_timediff = time() - strtotime($nineteen02_date);

	if($nineteen02_timediff < 60)

		return $nineteen02_timediff . 's';

	else if($nineteen02_timediff < 3600)

		return intval(date('i', $nineteen02_timediff)) . 'm';

	else if($nineteen02_timediff < 86400)

		return round($nineteen02_timediff/60/60) . 'h';

	else

		return date_i18n('M d', strtotime($nineteen02_date));

}	



function nineteen02_twitter_formatter($nineteen02_date)

{

	$nineteen02_epoch_timestamp = strtotime( $nineteen02_date );

	$nineteen02_twitter_time = human_time_diff($nineteen02_epoch_timestamp, current_time('timestamp') ) . ' ago';

	return $nineteen02_twitter_time;

}



require_once("twitterfeed/twitteroauth/twitteroauth.php"); //Path to twitteroauth library



function getConnectionWithAccessToken($cons_key, $cons_secret, $oauth_token, $oauth_token_secret)

{

	  $nineteen02_connection = new TwitterOAuth($cons_key, $cons_secret, $oauth_token, $oauth_token_secret);

	  return $nineteen02_connection;

}



function get_connect($nineteen02_consumerkey_gt, $nineteen02_consumersecret_gt, $nineteen02_accesstoken_gt, $nineteen02_accesstokensecret_gt,$nineteen02_twitteruser_gt,$nineteen02_notweets_gt)

{

	//session_start();

	$nineteen02_connection = getConnectionWithAccessToken($nineteen02_consumerkey_gt, $nineteen02_consumersecret_gt, $nineteen02_accesstoken_gt, $nineteen02_accesstokensecret_gt);

	$nineteen02_tweets_all = $nineteen02_connection->get("https://api.twitter.com/1.1/statuses/user_timeline.json?screen_name=".$nineteen02_twitteruser_gt."&count=".$nineteen02_notweets_gt);

	return $nineteen02_tweets_all;

}



/* Short code */

add_shortcode( 'Nineteen02GetTwitterFeeds' , 'nineteen02_get_twitter_feeds' );

function nineteen02_get_twitter_feeds($atts)

{

	extract( shortcode_atts( array(

		'nineteen02_username' => '',

		'nineteen02_numberoftweets' => '',

		'nineteen02_tweet_title' =>''

	), $atts ) );



	$nineteen02_get_twitteruser=$nineteen02_username ? $nineteen02_username : get_option('nineteen02_consumer_screen_name');

	$nineteen02_get_notweets=$nineteen02_numberoftweets ? $nineteen02_numberoftweets : get_option('nineteen02_display_number_of_tweets');

	$nineteen02_get_tweetstitle=$nineteen02_tweet_title ? $nineteen02_tweet_title:'Latest Twitter Feeds';

	$nineteen02_twitteruser = $nineteen02_get_twitteruser;

	$nineteen02_notweets = $nineteen02_get_notweets;

	$nineteen02_consumerkey = get_option('nineteen02_consumer_key');

	$nineteen02_consumersecret = get_option('nineteen02_consumer_secret');

	$nineteen02_accesstoken = get_option('nineteen02_access_token');

	$nineteen02_accesstokensecret = get_option('nineteen02_access_token_secret');

	$nineteen02_img_display=esc_attr(get_option('nineteen02_show_image'));

	$nineteen02_username_display=esc_attr(get_option('nineteen02_display_username'));

	$nineteen02_timestamp_display=esc_attr(get_option('nineteen02_display_timestamps'));

	$nineteen02_reply_display=esc_attr(get_option('nineteen02_reply_link'));

	$nineteen02_retweet_display=esc_attr(get_option('nineteen02_retweet_link'));

	$nineteen02_favorite_display=esc_attr(get_option('nineteen02_favorite_link'));

	$nineteen02_get_follow_button=esc_attr(get_option('nineteen02_follow_button'));
        
        //$nineteen02_miscmap=esc_attr(get_option('nineteen02_misc_map'));

		

			

	if($nineteen02_twitteruser!='' && $nineteen02_notweets !='' && $nineteen02_consumerkey!='' && $nineteen02_consumersecret!='' && $nineteen02_accesstoken!='' && $nineteen02_accesstokensecret!='' )

	{

		

		$nineteen02_tweets = get_connect($nineteen02_consumerkey, $nineteen02_consumersecret, $nineteen02_accesstoken, $nineteen02_accesstokensecret,$nineteen02_twitteruser,$nineteen02_notweets);

				
		if(is_admin())

		{

			$screen = get_current_screen(); 

			if($screen->id == 'dashboard')

			{

				 $nineteen02_wid_title="";

				 $nineteen02_class="";

			}

			else

			{

				 $nineteen02_wid_title="<h3 class='widget-title'>".$nineteen02_get_tweetstitle."</h3><ul class='twitter-feed'>";

				 $nineteen02_class="twitterwidgetscss widget";

			}

		}

		else

		{

			$nineteen02_wid_title="<h3 class='widget-title'>".$nineteen02_get_tweetstitle."</h3><ul class='twitter-feed'>";	

			$nineteen02_class="twitterwidgetscss widget";

		}

		

			

		$nineteen02_output="<div class='".$nineteen02_class."'>

					".$nineteen02_wid_title;				

				

					

		for($i=0;$i<count($nineteen02_tweets);$i++)

		{

			

			if($nineteen02_img_display=='Yes'){ $nineteen02_img_html='<img src="'.$nineteen02_tweets[$i]->user->profile_image_url_https.'" class="imgalign"/>';}else{$nineteen02_img_html='';}

			

			if($nineteen02_username_display=='Yes'){

				$nineteen02_username_html='<strong>

									<a href="https://twitter.com/intent/user?screen_name='.$nineteen02_tweets[$i]->user->screen_name.'" target="_blank">'.$nineteen02_tweets[$i]->user->name.'</a>

									</strong>';

			}else{$nineteen02_username_html='';}

			

			if($nineteen02_timestamp_display=='Yes'){

				$nineteen02_timestamp_html='<a href="https://twitter.com/'.$nineteen02_tweets[$i]->user->screen_name.'/status/'.$nineteen02_tweets[$i]->id_str.'" target="_blank">'.nineteen02_getTime($nineteen02_tweets[$i]->created_at).'</a>';

			}else{$nineteen02_timestamp_html='';}

			

			if($nineteen02_reply_display=='Yes'){$nineteen02_replay_html='<a target="_blank" href="https://twitter.com/intent/tweet?in_reply_to='.$nineteen02_tweets[$i]->id_str.'">reply</a>';}else{$nineteen02_replay_html='';}

			

			if($nineteen02_retweet_display=='Yes'){$nineteen02_retweet_html='<a target="_blank" href="https://twitter.com/intent/retweet?tweet_id='.$nineteen02_tweets[$i]->id_str.'">retweet</a>';}else{$nineteen02_retweet_html='';}

			

			if($nineteen02_favorite_display=='Yes'){$nineteen02_favorite_html='<a target="_blank" href="https://twitter.com/intent/favorite?tweet_id='.$nineteen02_tweets[$i]->id_str.'">favorite</a>';}else{$nineteen02_favorite_html='';}

			

			if($nineteen02_get_follow_button=='Yes'){

				

				$nineteen02_follow_html='<p class="thinkTwitFollow"><a href="https://twitter.com/'. $nineteen02_twitteruser.'" class="twitter-follow-button" data-show-count="false" data-dnt="true">Follow @'.$nineteen02_twitteruser.'</a></p>';

				

				$nineteen02_follow_html.='<script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0];if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src="//platform.twitter.com/widgets.js";fjs.parentNode.insertBefore(js,fjs);}}(document,"script","twitter-wjs");twttr.widgets.load();</script>';

				

			} else { 
      
       $nineteen02_follow_html='';
      }
      $imgclass='';
			if($nineteen02_img_html){
          $nineteen02_img_html = $nineteen02_img_html;
          $imgclass = 'wavatar';
      } else {
          $nineteen02_img_html = '<img src="'.get_template_directory_uri().'/includes/twitterfeed/twitter_icon.png" />';
          $imgclass = 'noavatar';
      }

			

			$nineteen02_output.='<li><div class="imgdisplay '.$imgclass.'">'.$nineteen02_img_html.'</div>

							<div class="tweettxts">

    							<div class="tweettext">'.$nineteen02_username_html.'
    
        							&nbsp;'.nineteen02_makeLink($nineteen02_tweets[$i]->text).'&nbsp
    
    							
    
        							<div class="tweetlink">
        
        								'.$nineteen02_timestamp_html.'
        
        								'.$nineteen02_replay_html.'
        
        								'.$nineteen02_retweet_html.'
        
        								'.$nineteen02_favorite_html.'
        
        								'.nineteen02_twitter_formatter($nineteen02_tweets[$i]->created_at).'
        
        							</div>

							</div>

						</div><div class="clear"></div>';

		}	

		

		$nineteen02_output.=$nineteen02_follow_html."</div>";
	

		//echo $nineteen02_output;

	}

	else

	{

		$nineteen02_output="<div id='twitterwidgetscss'>

					<h1>".$nineteen02_get_tweetstitle."</h1>

						<div>Please Fill All Required Value

						</div>

					<div>";

		//echo $nineteen02_output;			

	}

	return $nineteen02_output;

}



/*
 * Nineteen02 Twitter Widget Widget
 */

 class nineteen02_Twitter_Widget extends WP_Widget

 {

 	public function nineteen02_Twitter_Widget()

 	{

		$this->options = array(

			array(

				'label' => '<div style="background-color: #ddd; padding: 5px; text-align:center; color: red; font-weight:bold;">Nineteen02 Widget settings</div>',

				'type'	=> 'separator'),

			array(

				'name'	=> 'nineteen02_widget_title',	'label'	=> 'Widget title',

				'type'	=> 'text',	'default' => 'Latest Tweets', 'tooltip' => 'Title of the widget'),

			array(

				'name'	=> 'nineteen02_widget_username',	'label'	=> 'Username (Without the "@" symbol)',

				'type'	=> 'text',	'default' => 'twitter', 'tooltip' => 'Twitter username for which you want to display tweets if widget type is set to Timeline'),

			array(

				'name'	=> 'nineteen02_widget_count',	'label'	=> 'Tweet number',

				'type'	=> 'text',	'default' => '5', 'tooltip' => 'Number of Tweets to display'),

		);

		

		/* Widget settings. */
 		$widget_options = array(

			'classname' => 'nineteen02_widget',

			'description' => '1902 Simple Twitter Feed Widget, Displays your latest Tweet',

		);

		

		/* Widget control settings. */

		$control_ops = array('width' => 400);

		parent::WP_Widget('nineteen02_widget','1902 Twitter Feeds',$widget_options,$control_ops);

 	}

	

	public function widget($args, $instance)

	{
		$nineteen02_get_widget_twitteruser=$instance['nineteen02_widget_username'] ? $instance['nineteen02_widget_username'] : get_option('nineteen02_consumer_screen_name');

		$nineteen02_get_widget_notweets=$instance['nineteen02_widget_count'] ? $instance['nineteen02_widget_count'] : get_option('nineteen02_display_number_of_tweets');

		$title = ($instance['nineteen02_widget_title']) ? $instance['nineteen02_widget_title'] : 'Latest Twitter Feeds';

		

		$nineteen02_wid_twitteruser = $nineteen02_get_widget_twitteruser;

		$nineteen02_wid_notweets = $nineteen02_get_widget_notweets;

			

		extract($args, EXTR_SKIP);	

		

		$atts_arr=array('nineteen02_username' => $nineteen02_get_widget_twitteruser,

		'nineteen02_numberoftweets' => $nineteen02_get_widget_notweets,

		'nineteen02_tweet_title' =>$title);

		echo nineteen02_get_twitter_feeds($atts_arr);

	}

	function update($new_instance, $old_instance) {   
       return $new_instance;
   }

	public function form($instance)

	{

		if(empty($instance)) {

			foreach($this->options as $val) {

				if ($val['type'] == 'separator') {

					continue;

				}

				$instance[$val['name']] = $val['default'];

			}

		}					

	

		if (!is_callable('curl_init')) {

			echo __('Your PHP doesn\'t have cURL extension enabled. Please contact your host and ask them to enable it.');

			return;

		}

		

		foreach ($this->options as $val) {

			$title = '';

			if(!empty($val['tooltip'])) {

				$title = ' title="' . $val['tooltip'] . '"';

			}

			if($val['type'] == 'separator') {

				echo $val['label'] . '<br/ >';

			}

			else if($val['type'] == 'text') {

				$label = '<label for="' . $this->get_field_id($val['name']) . '" ' . $title . '>' . $val['label'] . '</label>';

				$value = $val['default'];

				if(isset($instance[$val['name']]))

					$value = esc_attr($instance[$val['name']]);

				echo '<p>' . $label . '<br />';

				echo '<input class="widefat" id="' . $this->get_field_id($val['name']) . '" name="' . $this->get_field_name($val['name']) . '" type="text" value="' . $value . '" ' . $title . '/></p>';

			}

		}

		//echo "<a href='".admin_url()."options-general.php?page=ai-plugin'> Go to More Settings</a>";

	}

 }


/*

* Register the nineteen02_Twitter_Widget

*/

function nineteen02_twitter_widget_init()

{

	register_widget('nineteen02_Twitter_Widget');

}

add_action('widgets_init', 'nineteen02_twitter_widget_init');


function customContent($args) {
     global $post;
     //echo $post->ID;
     // by mcr => Get only text of a post except images
     $mcrPostContent = strip_shortcodes(get_the_content($post->ID));               
     $mcrSearchImgs = '~<img [^\>]*\ />~';
     $mcrPostText = preg_replace( $mcrSearchImgs, '' , $mcrPostContent);
     $mcrPostText = apply_filters('the_content', $mcrPostText);
    
      
      $mcrSearchImgs = '~<img [^\>]*\ />~';
      preg_match_all( $mcrSearchImgs, $mcrPostContent, $aPics );
      $iNumberOfPics = count($aPics[0]);
      
      if($args=='text') {
          
                  return $mcrPostText;
          
      }
      if($args=='image') {
            
              if ( $iNumberOfPics > 0 )
              {
                   for ( $i=0; $i < $iNumberOfPics ; $i++ )
                   {
                        return $aPics[0][$i];
                   };
              };
                    
             
      }
}

// Get URL of first image in a post
function get_first_image() {
    global $post, $posts;
    $first_img = '';
    ob_start();
    ob_end_clean();
    $output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
    $first_img = $matches [1] [0];
    
    // no image found display default image instead
    if(empty($first_img)){
      $first_img = get_template_directory_uri()."/images/default.jpg";
    }
    return $first_img;
}

//**DISPLAYING SOCIALMEDIA SHARE LINKS ON NEWS***/
function displaySocialLinks(){
    global $post;
    $enable_facebook_like = esc_attr(get_option('enable_facebook_like'));
    $enable_twitter_button = esc_attr(get_option('enable_twitter_button'));
    $enable_gplus_button = esc_attr(get_option('enable_gplus_button'));
    $excerpt = customContent('text');
   
  
    $displaybuttons = esc_attr(get_option('displaybuttons'));
    $display_social_button = esc_attr(get_option('display_social_button'));
    $display_social_button_array = explode(',',str_replace(' ', '',$display_social_button));
                                
    $checkpostType = get_post_type();
    // echo '<pre>';
    // echo var_dump($display_social_button_array);
    //  echo '</pre>';
    //echo $checkpostType;
   
    if(in_array($checkpostType,$display_social_button_array)){
           if($enable_twitter_button == 'Yes'){ ?>    
              <a id="twitter-share" style='text-decoration:none;' type="icon_link" onClick="window.open('https://twitter.com/share?text=<?php the_title(); ?>&amp;url=<?php the_permalink(); ?>','sharer','toolbar=0,status=0,width=580,height=325');" href="javascript: void(0)">
                  <img src="<?php echo get_template_directory_uri()?>/images/btn-twitter.png" alt="Facebook like"/>
              </a>
          <?php  } 
          
            if($enable_facebook_like == 'Yes'){ ?>                            
              <a id="fb-share" style='text-decoration:none;' type="icon_link" onClick="window.open('http://www.facebook.com/sharer.php?s=100&amp;p[title]=<?php the_title(); ?>&amp;p[summary]=<?php echo substr($excerpt,0,50);?>&amp;p[url]=<?php the_permalink(); ?>&amp;p[images][0]=<?php echo get_first_image();?>','sharer','toolbar=0,status=0,width=580,height=325');" href="javascript: void(0)">
                  <img src="<?php echo get_template_directory_uri()?>/images/btn-facebook.png" alt="twitter share" title="twitter share+"/>
              </a>
          <?php  } 
          
           
           if($enable_gplus_button == 'Yes'){ ?> 
              <a href="https://plus.google.com/share?url=<?php the_permalink(); ?>" target="_blank">
                  <img src="<?php echo get_template_directory_uri()?>/images/btn-google.png" alt="Google+" title="Google+"/>
              </a>
        
          <?php  } 
    } 
    
}

            
//**ADD SET AS POPULAR IN POST***/
add_filter( 'post_row_actions', 'add_popular_row_action', 10, 2);
add_action( 'admin_head-edit.php', 'add_set_popular_action');
add_action( 'admin_notices', 'set_as_popular_admin_notices');

function add_popular_row_action($actions, $post)
	{
		$post_type = $post->post_type;
		
		//echo $post_type;
		
		if ($post_type == "post" || $post_type == "news" || $post_type == "product")
		{
			 $is_popular = (get_post_meta($post->ID, '_is_popular', true) == 1) ? get_post_meta($post->ID, '_is_popular', true) : null;
			
			if($is_popular)
			{
				$actions['remove_as_popular'] = '<a href="edit.php?post_type='.$post_type.'&remove_as_popular=1&post_id='.$post->ID.'&title='.$post->post_title.'">' . __('Remove as Popular', THEME_DOMAIN). '</a>';
			}
			else 
			{
				$actions['set_as_popular'] = '<a href="edit.php?post_type='.$post_type.'&set_as_popular=1&post_id='.$post->ID.'&title='.$post->post_title.'">' . __('Set as Popular', THEME_DOMAIN). '</a>';
			}
	    }
	    
	    return $actions;
	}
	
function add_set_popular_action()
	{
		global $typenow;
		
	//	echo $typenow;
		
	    if( 'news' != $typenow && 'post' != $typenow && 'product' != $typenow)
	        return;
	
	    if( isset( $_GET['set_as_popular'] ) )
	    {
	    	update_post_meta($_GET['post_id'], '_is_popular', 1);
	    }
	    
		if( isset( $_GET['remove_as_popular'] ) )
	    {
		    update_post_meta($_GET['post_id'], '_is_popular', 0);
	    }
	}

function set_as_popular_admin_notices() 
	{
		global $pagenow, $post;
		$message = '';
		

		
		if($pagenow == 'edit.php') 
		{
			if($post)
			{
				$post_type = get_post_type($post->ID);
			
				if ($post_type == 'post' || $post_type == 'news' || $post_type == 'product')
				{
					$post = get_post($post->ID);
					
          //var_dump($post);
					//exit();
					
					if(isset($_REQUEST['set_as_popular']))
					{
					 
						$message = sprintf(__( '<strong>%s</strong> is set as popular.', THEME_DOMAIN), $_REQUEST['title']);
					}
					elseif(isset($_REQUEST['remove_as_popular']))
					{
						$message = sprintf(__( '<strong>%s</strong> is removed as popular.', THEME_DOMAIN), $_REQUEST['title']);
					}
			
					if($message)
					{
					?>
						<div class="updated">
					        <p><?php echo $message ?></p>
					    </div>
					<?php 
					}
				}
			}
		}
}


/*MOST POPULAR WIDGET -> TO BE USED ON SIDEBARS*/
function getMostPopular(){
   
   $args = array( 'post_type' => array('post','news','product'),
                   'post_status' => 'publish',
                   'posts_per_page' => 4,
                   'orderby'=>'DATE',
                   'order' => 'DESC',
                   'meta_query' => array(
                                         array(
                                             'key' => '_is_popular',
                                             'value' => 1,
                                             'compare' => '=',
                                         )
                                     )
    		);  

    $most_popular = new WP_Query($args);
    require_once('mostpopular/most-popular.phtml');
}
add_shortcode('mostpopular','getMostPopular');



add_action('widgets_init', array('MostPopularWidget', 'registerMostPopularWidget'));
class MostPopularWidget extends WP_Widget
{
	public function __construct() 
	{
		$widget_options = array('description' => __('Displays Most Popular Post set as popular on post row action', THEME_DOMAIN));
		parent::WP_Widget( 'most-popular-widget', __('1902 Most Popular Posts', THEME_DOMAIN), $widget_options );        
	}
	
	public function registerMostPopularWidget()
	{
		register_widget('MostPopularWidget');        
	}    
      
	function form( $instance )
	{		
		$defaults = array( 'title' => __('1902 Most Popular', THEME_DOMAIN));
		$instance = wp_parse_args( (array) $instance, $defaults );
		$title = strip_tags($instance['title']); 
	  $limit    = isset( $instance['limit'] ) ? absint( $instance['limit'] ) : 5;	
		echo'
			<p>
				<label>'._e('Title', THEME_DOMAIN).'</label> 
				<input id="'.  $this->get_field_id( 'title' ).'" class="widefat" name="'.$this->get_field_name('title').'" type="text" value="'.esc_attr($title).'" />
			</p>
			';
		//number of news to show
    echo'<p>
            <label for="'.$this->get_field_id( 'limit' ).'">'._e( 'Number of post to show:').'</label>
            <input id="'.$this->get_field_id( 'limit' ).'" name="'.$this->get_field_name( 'limit' ).'" type="text" value="'.$limit.'" size="3" />
        </p>';
			
	}
	
	function widget( $args, $instance )
	{
		global $wp_query;
		
		    $before_widget = $args[ 'before_widget' ];
        $before_title = $args[ 'before_title' ];
        $title = apply_filters('widget_title', $instance['title'] );
        $after_title = $args[ 'after_title' ];
        $after_widget = $args[ 'after_widget' ];
        $limit    = isset( $instance['limit'] ) ? absint( $instance['limit'] ) : 5;
        	
		    $args = array( 'post_type' => 'post',
                   'post_status' => 'publish',
                   'posts_per_page' => $limit,
                   'meta_query' => array(
                                         array(
                                             'key' => '_is_popular',
                                             'value' => 1,
                                             'compare' => '=',
                                         )
                                     )
    	 	);  

        $most_popular = new WP_Query($args);
        
        require_once('mostpopular/most-popular.phtml');
	}

	function update( $new_instance, $old_instance )
	{
		$instance = $old_instance; 
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['limit'] = strip_tags($new_instance['limit']);
		
		return $instance;  
	} 
}


//get slider setting to retrieve the data
function nineteeno2_slider(){
  $option_base = get_option('wptheme03');
  
  //data
  $slider_display_post = $option_base['slider_display_post'];
  //$slider_include_category = $option_base['slider_include_category'];
  $slider_include_category = $option_base['slider_include_category'];
  
       
  $slider_orderby = strtolower($option_base['slider_orderby']);
  $slider_no_of_slides = $option_base['slider_no_of_slides'];
  $slider_image_link = isset($option_base['slider_image_link']) ? $option_base['slider_image_link'] : '';
  $slider_max_width = $option_base['slider_max_width'];
  $slider_max_height = $option_base['slider_max_height'];
  $slider_display_title = isset($option_base['slider_display_title']) ? $option_base['slider_display_title'] : '';
  $slider_display_content = isset($option_base['slider_display_content']) ? $option_base['slider_display_content'] : '';
  $slider_display_type_content = $option_base['slider_display_type_content'];
  
  //jquery
  $slider_effect = strtolower($option_base['slider_effect']);
  $slider_speed = $option_base['slider_speed'];
  $slider_display_pagination = isset($option_base['slider_display_pagination']) ? $option_base['slider_display_pagination'] : ''; 
  $slider_hide_title_content  = isset($options['slider_hide_title_content']) ? $options['slider_hide_title_content'] : '';
  
    
  $slider_more_text = $option_base['slider_more_text'];
  $slider_limit_content = $option_base['slider_limit_content'];
  // $slider_display_arrow = $option_base['slider_display_arrow']; //remove as per ryan

  if($slider_include_category =='allcat' || $slider_include_category=='allcatterms')
    $slider_include_category = '';
    else
    $slider_include_category = $slider_include_category;
  
  //check if exlude or include value
  $slider_inc_exl_tax_post = $option_base['slider_inc_exl_tax_post'];
  $slider_include_exclude_terms = $option_base['slider_include_exclude_terms'];
   if(!empty($slider_include_exclude_terms))
    $slider_include_exclude_terms_array = explode(',',str_replace(' ', '',$slider_include_exclude_terms));
    else 
    $slider_include_exclude_terms_array = $slider_include_exclude_terms;
    
    
  $slider_include_exclude_post = $option_base['slider_include_exclude_post'];
  $slider_include_exclude_post_array = explode(',',str_replace(' ', '',$slider_include_exclude_post));
  
   if(!empty($slider_include_exclude_post))
    $slider_include_exclude_post_array = explode(',',str_replace(' ', '',$slider_include_exclude_post));
    else 
    $slider_include_exclude_post_array = $slider_include_exclude_post;
    
$args ='';
if($slider_inc_exl_tax_post =='Include'){  
    $args = array(
          	'post_type' => $slider_display_post,
          	'post_status' => 'publish',
          	'cat' => $slider_include_category,
          	'category__in' => $slider_include_exclude_terms_array,
          	'post__in' => $slider_include_exclude_post_array,
          	'orderby' => $slider_orderby,
          	'order' => 'ASC',
          	'posts_per_page'  => $slider_no_of_slides
    );
}  else {
    $args = array(
          	'post_type' => $slider_display_post,
          	'post_status' => 'publish',
          	'cat' => $slider_include_category,
          	'category__not_in' => $slider_include_exclude_terms_array,
          	'post__not_in' => $slider_include_exclude_post_array,
          	'orderby' => $slider_orderby,
          	'order' => 'ASC',
          	'posts_per_page'  => $slider_no_of_slides
    );
}
  
     
// echo '<pre>';
// var_dump($args);
// echo '</pre>';
  
  $sliders = new WP_Query( $args );
  require_once('slider/view/slider.phtml');
  wp_reset_postdata();
}


/*Socialmedia Setting*/
add_action('widgets_init', array('Nineteen02SocialMediaWidget', 'registerNineteen02SocialMediaWidget'));
class Nineteen02SocialMediaWidget extends WP_Widget
{
	public function __construct() 
	{
		$widget_options = array('description' => __('Displays Social Media Setting', THEME_DOMAIN));
		parent::WP_Widget( 'social-media-widget', __('1902 Social Media Setting', THEME_DOMAIN), $widget_options );        
	}
	
	public function registerNineteen02SocialMediaWidget()
	{
		register_widget('Nineteen02SocialMediaWidget');        
	}    
      
	function form( $instance )
	{		
		$defaults = array( 'title' => __('1902 Social Media Setting', THEME_DOMAIN));
		$instance = wp_parse_args( (array) $instance, $defaults );
		$title = strip_tags($instance['title']); 
		$fbaccount = strip_tags($instance['fbaccount']); 
		$gplusaccount = strip_tags($instance['gplusaccount']); 
		$pinterestaccount = strip_tags($instance['pinterestaccount']); 
                $twitteraccount = strip_tags($instance['twitteraccount']); 
		
		echo '
			<p>
				<label>'._e('Facebook', THEME_DOMAIN).'</label> 
				<input id="'.  $this->get_field_id( 'fbaccount' ).'" class="widefat" name="'.$this->get_field_name('fbaccount').'" type="text" value="'.esc_attr($fbaccount).'" />
			</p>
			';
		  echo '
  			<p>
  				<label>'._e('Google+', THEME_DOMAIN).'</label> 
  				<input id="'.  $this->get_field_id( 'gplusaccount' ).'" class="widefat" name="'.$this->get_field_name('gplusaccount').'" type="text" value="'.esc_attr($gplusaccount).'" />
  			</p>
			';
		echo '
			<p>
				<label>'._e('Twitter', THEME_DOMAIN).'</label> 
				<input id="'.  $this->get_field_id( 'twitteraccount' ).'" class="widefat" name="'.$this->get_field_name('twitteraccount').'" type="text" value="'.esc_attr($twitteraccount).'" />
			</p>
			';
                echo '
  			<p>
  				<label>'._e('Pinterest', THEME_DOMAIN).'</label> 
  				<input id="'.  $this->get_field_id( 'pinterestaccount' ).'" class="widefat" name="'.$this->get_field_name('pinterestaccount').'" type="text" value="'.esc_attr($pinterestaccount).'" />
  			</p>
			';
	}
	
	function widget( $args, $instance )
	{
	
		
		    $before_widget = $args[ 'before_widget' ];
        $before_title = $args[ 'before_title' ];
        $title = apply_filters('widget_title', $instance['title'] );
        $after_title = $args[ 'after_title' ];
        $after_widget = $args[ 'after_widget' ];
        
        $fbaccount = isset( $instance['fbaccount'] ) ?  $instance['fbaccount'] : '';
  		  $gplusaccount = isset( $instance['gplusaccount'] ) ? $instance['gplusaccount'] : '';
  		  $pinterestaccount = isset( $instance['pinterestaccount'] ) ? $instance['pinterestaccount']  : '';
  	    $twitteraccount = isset( $instance['twitteraccount'] ) ? $instance['twitteraccount']  : ''; 
	  
        require_once('socialmedia/socialmedia.phtml');
	}

	function update( $new_instance, $old_instance )
	{
		$instance = $old_instance; 
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['fbaccount'] = strip_tags($new_instance['fbaccount']);
		$instance['gplusaccount'] = strip_tags($new_instance['gplusaccount']);
		$instance['pinterestaccount'] = strip_tags($new_instance['pinterestaccount']);
		$instance['twitteraccount'] = strip_tags($new_instance['twitteraccount']);
		
		return $instance;  
	} 
}